@@ -443,9 +443,11 @@ void e_vsch_block(x, y, bv, bz, f)
    while(bz->mxlines+n > bz->mx.y-2)
    {  bz->mx.y += MAXLINES;
       if((tmp = REALLOC(bz->bf, bz->mx.y * sizeof(STRING))) == NULL)
-      e_error(e_msg[0], 1, bz->fb);
+	 e_error(e_msg[0], 1, bz->fb);
       else
-      bz->bf = tmp;
+	 bz->bf = tmp;
+      if(bz->f->c_sw) bz->f->c_sw = REALLOC(bz->f->c_sw ,
+	 bz->mx.y * sizeof(int));
    }
    if((str = MALLOC((n+2) * sizeof(STRING))) == NULL)
    {  e_error(e_msg[0], 0, bz->fb);
@@ -611,9 +613,11 @@ void e_copy_block(x, y, bv, bz, f)
    while(bz->mxlines+n > bz->mx.y-2)
    {  bz->mx.y += MAXLINES;
       if((tmp = REALLOC(bz->bf, bz->mx.y * sizeof(STRING))) == NULL)
-      e_error(e_msg[0], 1, bz->fb);
+	 e_error(e_msg[0], 1, bz->fb);
       else
-      bz->bf = tmp;
+	 bz->bf = tmp;
+      if(bz->f->c_sw) bz->f->c_sw = REALLOC(bz->f->c_sw ,
+	 bz->mx.y * sizeof(int));
    }
    if((str = MALLOC((n+2) * sizeof(STRING *))) == NULL)
    {  e_error(e_msg[0], 0, bz->fb);
