@@ -397,13 +397,13 @@ int e_eingabe(e)
       {  ret = e_tst_cur(c, e);
 	 if(ret != 0) ret = e_tst_fkt(c, e);
       }
-      s->ks.x = b->b.x;  s->ks.y = b->b.y;
       weiter:
-          b = e->f[e->mxedt]->b;
-      s = e->f[e->mxedt]->s;
       f = e->f[e->mxedt];
       if(e->mxedt > 0 && f->dtmd > 'Z')
-      {  e_cursor(f, 1);
+      {  b = f->b;
+         s = f->s;
+         s->ks.x = b->b.x;  s->ks.y = b->b.y;
+         e_cursor(f, 1);
 	 if((c & 511) != CUP && (c & 511) != CDO) b->clsv = b->cl;
 	 e_zlsplt(f);
       }
