@@ -22,6 +22,7 @@ int e_read_info();
 int e_switch_screen();
 
 char *info_file = NULL;
+char *e_tmp_dir = NULL;
 
 char *e_getedpath(fl)
      char *fl;
@@ -53,7 +54,14 @@ char *e_mkfilename(dr, fn)
      char *dr;
      char *fn;
 {
-   char *fl = MALLOC(strlen(dr) + strlen(fn) + 2);
+   char *fl;
+   if(!fn) return(NULL);
+   if(!dr)
+   {  fl = MALLOC(strlen(fn) + 1);
+      strcpy(fl, fn);
+      return(fl);
+   }
+   fl = MALLOC(strlen(dr) + strlen(fn) + 2);
    strcpy(fl, dr);
 #ifdef DJGPP
    if(dr[0] != '\0' && dr[strlen(dr)-1] != DIRC 
@@ -290,6 +298,7 @@ int e_quit(f)
      FENSTER *f;
 {
    int i;
+   char tmp[128];
 #if  MOUSE
    int g[4];
 #endif
@@ -308,6 +317,8 @@ int e_quit(f)
 #endif
 #ifdef UNIX
    if(e_quit_wastebasket(cn->f[0])) return(0);
+   sprintf(tmp, "rm -rf %s&", e_tmp_dir);
+   system(tmp);
 #endif
 #if  MOUSE
    g[0] = 2;
@@ -703,7 +714,7 @@ int e_file_window(sw, fw, ft, fz)
 			&& ( *(fw->df->name[i]+c) <= 32
 			  || *(fw->df->name[i]+c) >= 127); c++);
 #ifdef UNIX
-	       if(!(e_we_sw & 1)) c += 3;
+	       if(!(e_we_sw & 1) && *(fw->df->name[i]+c-1) == 32) c += 3;
 #endif
 	       if(strncmp(fw->df->name[i]+c, sustr, nsu) >= 0) break;
 	    }
@@ -883,16 +894,101 @@ struct help_ud {  struct help_ud *next;  char *str, *nstr, *pstr, *file;
         	  int x, y, sw;
                } *ud_help;
 
+typedef struct {  FILE *fp;  int sw;  } IFILE;
+
+#define e_i_fgets(s, n, p) fgets(s, n, p->fp)
+
+int e_mkdir_path(path)
+     char *path;
+{
+   int i, len;
+   char *tmp = MALLOC(((len=strlen(path))+1)*sizeof(char));
+   if(!tmp) return(-1);
+   strcpy(tmp, path);
+   for(i = len; i > 0 && tmp[i] != DIRC; i--);
+   if(i > 0)
+   {  tmp[i] = '\0';
+      if(access(tmp, 0))
+      {  e_mkdir_path(tmp);
+         mkdir(tmp, 0700);
+      }
+   }
+   FREE(tmp);
+   return(0);
+}
+
+IFILE *e_i_fopen(path, stat)
+     char *path;
+     char *stat;
+{
+   extern char *e_tmp_dir;
+   char *tmp, *tmp2, *command;
+   int len;
+   IFILE *fp = MALLOC(sizeof(IFILE));
+   if(!fp) return(NULL);
+   if(!path) {  FREE(fp); return(NULL);  }
+   if((fp->fp = fopen(path, stat))) {  fp->sw = 0;  return(fp);  }
+   if(!(tmp2 = MALLOC((strlen(path)+11)*sizeof(char)))) 
+   {  FREE(fp);  return(NULL);  }
+   strcpy(tmp2, path);
+   strcat(tmp2, ".info");
+   if((fp->fp = fopen(tmp2, stat))) 
+   {  FREE(tmp2);  fp->sw = 0;  return(fp);  }
+   strcpy(tmp2, path);
+   strcat(tmp2, ".gz");
+   if(access(tmp2, 0))
+   {  strcpy(tmp2, path);
+      strcat(tmp2, ".Z");
+      if(access(tmp2, 0))
+      {  strcpy(tmp2, path);
+	 strcat(tmp2, ".info.gz");
+	 if(access(tmp2, 0))
+	 {  strcpy(tmp2, path);
+	    strcat(tmp2, ".info.Z");
+	    if(access(tmp2, 0))
+	    {  FREE(fp); FREE(tmp2); return(NULL);  }
+	 }
+      }
+   }
+   if(!(tmp = MALLOC((strlen(path)+(len=strlen(e_tmp_dir))+2)*sizeof(char)))) 
+   {  FREE(fp);  FREE(tmp2);  return(NULL);  }
+   strcpy(tmp, e_tmp_dir);
+   if(path[0] != DIRC) {  tmp[len] = DIRC;  tmp[len+1] = '\0';  }
+   strcat(tmp, path);
+   if((fp->fp = fopen(tmp, stat)))
+   {  fp->sw = 1;  FREE(tmp);  FREE(tmp2);  return(fp);  }
+   command = MALLOC((strlen(tmp) + strlen(tmp2) + 14) * sizeof(char));
+   if(!command) {  FREE(fp);  FREE(tmp);  FREE(tmp2);  return(NULL);  }
+   e_mkdir_path(tmp);
+   sprintf(command, "gunzip < %s > %s", tmp2, tmp);
+   FREE(tmp2);
+   system(command);
+   FREE(command);  
+   fp->fp = fopen(tmp, stat);
+   FREE(tmp);
+   if(!fp->fp) {  FREE(fp);  return(NULL);  }
+   fp->sw = 1;
+   return(fp);  
+}
+
+int e_i_fclose(fp)
+     IFILE *fp;
+{
+   int ret = fclose(fp->fp);
+   FREE(fp);
+   return(ret);
+}
+
 int e_read_help(str, f, sw)
      char *str;
      FENSTER *f;
      int sw;
 {
-   FILE *fp;
+   IFILE *fp;
    char *ptmp, tstr[256];
    int i;
    ptmp = e_mkfilename(f->ed->libdrct, WE_HELP_ED);
-   fp = fopen(ptmp, "rb");
+   fp = e_i_fopen(ptmp, "rb");
    FREE(ptmp);
    if(!fp) return(1);
    e_close_buffer(f->b);
@@ -915,7 +1011,7 @@ int e_read_help(str, f, sw)
 #endif
    e_new_line(0, f->b);
    if(str && str[0])
-   {  while((ptmp = fgets(tstr, 256, fp)) && !e_strcstr(tstr, str));
+   {  while((ptmp = e_i_fgets(tstr, 256, fp)) && !e_strcstr(tstr, str));
       if(ptmp && !sw)
       {  strcpy(f->b->bf[f->b->mxlines-1].s, tstr);
 	 f->b->bf[f->b->mxlines-1].len = e_str_len(f->b->bf[f->b->mxlines-1].s);
@@ -925,11 +1021,11 @@ int e_read_help(str, f, sw)
    if(sw)
    {  char *tp = NULL, tmp[128], ts[2];
       ts[0] = HHD; ts[1] = '\0';
-      while((ptmp = fgets(tstr, 256, fp)) && !(tp = strstr(tstr, ts)));
+      while((ptmp = e_i_fgets(tstr, 256, fp)) && !(tp = strstr(tstr, ts)));
       if(!str || !str[0])
-         while((ptmp = fgets(tstr, 256, fp)) && !(tp = strstr(tstr, ts)));
+         while((ptmp = e_i_fgets(tstr, 256, fp)) && !(tp = strstr(tstr, ts)));
       if(!ptmp)
-      {  fclose(fp);
+      {  e_i_fclose(fp);
 	 return(e_error("No Next Page", 0, f->fb));
       }
       else
@@ -942,15 +1038,15 @@ int e_read_help(str, f, sw)
 	 f->b->bf[f->b->mxlines-1].nrc = e_str_nrc(f->b->bf[f->b->mxlines-1].s);
       }
    }
-   while(fgets(tstr, 256, fp))
+   while(e_i_fgets(tstr, 256, fp))
    {  for(i = 0; tstr[i]; i++)
-      if(tstr[i] == HFE)  {  fclose(fp);  return(0);  }
+      if(tstr[i] == HFE)  {  e_i_fclose(fp);  return(0);  }
       e_new_line(f->b->mxlines, f->b);
       strcpy(f->b->bf[f->b->mxlines-1].s, tstr);
       f->b->bf[f->b->mxlines-1].len = e_str_len(f->b->bf[f->b->mxlines-1].s);
       f->b->bf[f->b->mxlines-1].nrc = e_str_nrc(f->b->bf[f->b->mxlines-1].s);
    }
-   fclose(fp);
+   e_i_fclose(fp);
    return(2);
 }
 
@@ -1212,8 +1308,10 @@ int e_mk_info_button(str)
 {
    int i, bg, nd, len = strlen(str);
    if(str[0] == '\n' || str[0] == '\0') return(1);
-   for(bg = 0; str[bg] && !isalnum1(str[bg]); bg++);
-   for(nd = bg; str[nd] && str[nd] != ':'; nd++);
+   for(bg = 0; str[bg] && isspace(str[bg]); bg++);
+   for(nd = bg; str[nd] && (str[nd] != ':' || 
+      (!isspace(str[nd+1]) && (str[nd+1] != ':' || 
+       (!isspace(str[nd+2]) && str[nd+2] != '.')))); nd++);
    if(!str[nd]) return(-1);
    if(str[nd+1] != ':')
    {  for(nd++; str[nd] && isspace(str[nd]); nd++);
@@ -1225,8 +1323,10 @@ int e_mk_info_button(str)
          if(str[nd]) str[nd] = HED;
          return(0);
       }
-      for(bg = nd; str[nd] && str[nd] != '.'; nd++);
+      for(; str[nd] && (str[nd] != '.' || isalnum1(str[nd+1])); nd++);
       if(!str[nd]) return(-1);
+      for(bg = nd; str[bg] != ':' || !isspace(str[bg+1]); bg--);
+      for(bg++; isspace(str[bg]); bg++);
    }
    for(i = len; i >= nd; i--) str[i+2] = str[i];
    str[nd+1] = HED;
@@ -1247,16 +1347,16 @@ int e_mk_info_mrk(str)
    return(0);
 }
 
-FILE *e_info_jump(str, path, fp)
+IFILE *e_info_jump(str, path, fp)
      char *str;
      char **path;
-     FILE *fp;
+     IFILE *fp;
 {
-   FILE *fpn;
+   IFILE *fpn;
    int i, j, n, anz = 0;
    char *ptmp, *fstr, tstr[256], nfl[128];
    struct FL_INFO{  char *name; int line;  } **files = MALLOC(1);
-   while(fgets(tstr, 256, fp) && tstr[0] != IFE)
+   while(e_i_fgets(tstr, 256, fp) && tstr[0] != IFE)
    {  for(i = 0; (nfl[i] = tstr[i]) && tstr[i] != ':'; i++);
       if(!tstr[i]) continue;
       nfl[i] = '\0';
@@ -1271,24 +1371,33 @@ FILE *e_info_jump(str, path, fp)
    fstr = MALLOC((i+1) * sizeof(char));
    strcat(strcpy(fstr, "Node: "), str);
    if(fstr[n = strlen(fstr)-1] == HED) {  fstr[n] = '\0';  i--;  }
-   while((ptmp = fgets(tstr, 256, fp)) && strncmp(tstr, fstr, i));
+   while((ptmp = e_i_fgets(tstr, 256, fp)) && strncmp(tstr, fstr, i));
    if(ptmp)
    {  n = atoi(tstr+i+1);
       for(i = 1; i < anz && n >= files[i]->line; i++);
+#ifdef DJGPP
+      if(files[i-1]->name[0] == DIRC || files[i-1]->name[0] == '/')
+#else
       if(files[i-1]->name[0] == DIRC)
+#endif
       {  ptmp = MALLOC((strlen(files[i-1]->name)+1)*sizeof(char));
          strcpy(ptmp, files[i-1]->name);
       }
       else
+#ifdef DJGPP
+      {  for(n = strlen(*path)-1; n >= 0 && *(*path+n) != DIRC 
+            && *(*path+n) != '/'; n--);
+#else
       {  for(n = strlen(*path)-1; n >= 0 && *(*path+n) != DIRC; n--);
+#endif
          n++;
          ptmp = MALLOC((strlen(files[i-1]->name)+n+1)*sizeof(char));
          for(j = 0; j < n; j++) ptmp[j] = *(*path+j);
          ptmp[j] = '\0';
          strcat(ptmp, files[i-1]->name);
       }
-      if((fpn = fopen(ptmp, "rb")) != NULL)
-      {  fclose(fp);
+      if((fpn = e_i_fopen(ptmp, "rb")) != NULL)
+      {  e_i_fclose(fp);
          fp = fpn;
          FREE(*path);
          *path = ptmp;
@@ -1324,35 +1433,64 @@ char *e_mk_info_pt(str, node)
    return(ptmp);
 }
 
+char *e_mk_info_path(path, file)
+     char *path;
+     char *file;
+{
+   int n = 0;
+   char *tp;
+   if(!info_file) return(NULL);
+#ifdef DJGPP
+   if(file[0] == DIRC || file[0] == '/')
+#else
+   if(file[0] == DIRC)
+#endif
+   {  if(path && !strcmp(path, file)) {  FREE(path);  return(NULL);  }
+      else if(path) FREE(path);
+      if(!(path = MALLOC((strlen(file) + 1) * sizeof(char)))) return(NULL);;
+      return(strcpy(path, file));
+   }
+   if(path)
+   {  n = strlen(path) - strlen(file) - 1;
+      if(n > 0) path[n] = '\0';
+      else if(n == 0) path[n+1] = '\0';
+      n = strlen(path);
+      for(tp = info_file; (tp = strstr(tp, path)) != NULL
+         	&& tp[n] && tp[n] != PTHD; tp++);
+      FREE(path);
+      if(!tp) return(NULL);
+      for(n = 0; info_file+n <= tp || (tp[n] && tp[n] != PTHD); n++);
+      if(!tp[n]) return(NULL);
+      n++;
+   }
+   tp = info_file + n;
+   for(n = 0; tp[n] && tp[n] != PTHD; n++);
+   if(!(path = MALLOC((strlen(file) + n + 2) * sizeof(char)))) return(NULL);
+   for(n = 0; (path[n] = tp[n]) && tp[n] != PTHD; n++);
+   if(n > 1)
+   {  path[n] = DIRC;  n++;  }
+   path[n] = '\0';
+   return(strcat(path, file));
+}
+
 int e_read_info(str, f, file)
      char *str;
      FENSTER *f;
      char *file;
 {
-   FILE *fp;
-   char *path, *ptmp, tstr[256], fstr[128];
+   IFILE *fp = NULL;
+   char *path = NULL, *ptmp, tstr[256], fstr[128];
    int i, len, sw = 0, bsw = 0;
    if(!str) str = "Top";
    if(str[0] == HHD) str++;
    strcat(strcpy(fstr, "Node: "), str);
    len = strlen(fstr);
    if(fstr[len-1] == HED) fstr[len-1] = '\0';
-   if(!file || !file[0])
-   {  path = MALLOC((strlen(info_file)+1)*sizeof(char));
-      strcpy(path, info_file);
-   }
-   else if(file[0] != DIRC)
-   {  path = MALLOC((strlen(info_file)+strlen(file)+2)*sizeof(char));
-      strcpy(path, info_file);
-      for(i = strlen(path)-1; i >= 0 && path[i] != DIRC; i--);
-      path[i+1] = '\0';
-      strcat(path, file);
-   }
-   else
-   {  path = MALLOC((strlen(file)+1)*sizeof(char));
-      strcpy(path, file);
-   }
-   fp = fopen(path, "rb");
+   if(!file || !file[0]) file = "dir";
+   do
+   {  path = e_mk_info_path(path, file);
+      fp = e_i_fopen(path, "rb");
+   } while(!fp && path);
    if(!fp) return(1);
    e_close_buffer(f->b);
    if( (f->b = (BUFFER *) MALLOC(sizeof(BUFFER))) == NULL)
@@ -1373,7 +1511,7 @@ int e_read_info(str, f, file)
    f->b->ud = NULL;
 #endif
    e_new_line(0, f->b);
-   while((ptmp = fgets(tstr, 256, fp)) != NULL)
+   while((ptmp = e_i_fgets(tstr, 256, fp)) != NULL)
    {  if(!strncmp(tstr, "Indirect:", 9)) fp = e_info_jump(str, &path, fp);
       else if(!strncmp(tstr, "File:", 5) && strstr(tstr, fstr)) break;
    }
@@ -1382,7 +1520,10 @@ int e_read_info(str, f, file)
    {  ud_help->nstr = e_mk_info_pt(tstr, "Next");
       ud_help->pstr = e_mk_info_pt(tstr, "Prev");
    }
-   while((ptmp = fgets(tstr, 256, fp)) && isspace(tstr[0]));
+   if(!strcmp(file, "dir"))
+      while((ptmp = e_i_fgets(tstr, 256, fp)) 
+         && e_strcncmp(tstr, "* Menu:", 7));
+   else while((ptmp = e_i_fgets(tstr, 256, fp)) && tstr[0] == '\n');
    if(ptmp)
    {  if(!sw && !e_strcncmp(tstr, "* Menu:", 7)) sw = 1;
       for(i = len = strlen(tstr); i >= 0; i--) tstr[i+1] = tstr[i];
@@ -1391,21 +1532,32 @@ int e_read_info(str, f, file)
       f->b->bf[f->b->mxlines-1].len = e_str_len(f->b->bf[f->b->mxlines-1].s);
       f->b->bf[f->b->mxlines-1].nrc = e_str_nrc(f->b->bf[f->b->mxlines-1].s);
    }
-   while(fgets(tstr, 256, fp))
+   while(e_i_fgets(tstr, 256, fp))
    {  for(i = 0; tstr[i]; i++)
-      if(tstr[i] == IFE)  {  fclose(fp);  return(0);  }
-      if(bsw == 1) bsw = e_mk_info_button(tstr);
+      if(tstr[i] == IFE)  {  e_i_fclose(fp);  return(0);  }
+      if(bsw == 1) 
+      {  bsw = e_mk_info_button(tstr);
+         for(ptmp = tstr; (ptmp = e_strcstr(ptmp, "*note")); ptmp += 5)
+            bsw = e_mk_info_button(ptmp+5);
+      }
       else if(!sw && !e_strcncmp(tstr, "* Menu:", 7)) sw = 1;
-      else if(sw && tstr[0] == '*') bsw = e_mk_info_button(tstr+1);
-      else if((ptmp = e_strcstr(tstr, "*note"))  
-         || (ptmp = e_strcstr(tstr, "*note"))) bsw = e_mk_info_button(ptmp+5);
+      else if((ptmp = e_strcstr(tstr, "*note")))
+      {  bsw = e_mk_info_button(ptmp+5);
+         for(ptmp += 5; (ptmp = e_strcstr(ptmp, "*note")); ptmp += 5)
+            bsw = e_mk_info_button(ptmp+5);
+      }
+      else if(sw && tstr[0] == '*') 
+      {  bsw = e_mk_info_button(tstr+1);
+         for(ptmp = tstr+1; (ptmp = e_strcstr(ptmp, "*note")); ptmp += 5)
+            bsw = e_mk_info_button(ptmp+5);
+      }
       e_mk_info_mrk(tstr);
       e_new_line(f->b->mxlines, f->b);
       strcpy(f->b->bf[f->b->mxlines-1].s, tstr);
       f->b->bf[f->b->mxlines-1].len = e_str_len(f->b->bf[f->b->mxlines-1].s);
       f->b->bf[f->b->mxlines-1].nrc = e_str_nrc(f->b->bf[f->b->mxlines-1].s);
    }
-   fclose(fp);
+   e_i_fclose(fp);
    return(2);
 }
 
