@@ -16,6 +16,7 @@
 struct dirfile *e_make_win_list();
 int e_s_sys_ini();
 int e_s_sys_end();
+extern char *e_tmp_dir;
 
 #ifdef NOSYMLINKS
 #define readlink(x, y, z) -1
@@ -363,8 +364,9 @@ int e_file_eingabe(cn)
    if(f->dtmd != 'F') return(0);
    
    if(f->save == 1)
-   {  svmode = f->ed->flopt;  f->ed->flopt = 010023;
-      svdir = MALLOC((strlen(f->ed->dirct)+1)*sizeof(char));
+   {  svmode = f->ed->flopt;  f->ed->flopt = 010023;  }
+   if(f->save == 1 || b->sw == 5)
+   {  svdir = MALLOC((strlen(f->ed->dirct)+1)*sizeof(char));
       strcpy(svdir, f->ed->dirct);
    }
    nco = b->cd->anz - 1;
@@ -914,15 +916,29 @@ int e_file_eingabe(cn)
 	    }
 	    else if(c == ESC || (!(f->ed->edopt & 1) && c == AF3)
 				|| (f->ed->edopt & 1 && c == CF4))
-	    {  e_close_window(f);
+            {  chdir(svdir);
+	       getcwd(f->dirct, 80);
+	       if((f->ed->dirct = REALLOC(f->ed->dirct,
+		  strlen(f->dirct)+1)) == NULL)
+		  e_error(e_msg[0], 0, f->fb);
+	       else  strcpy(f->ed->dirct, f->dirct);
+	       e_close_window(f);
 	       return(ESC);
 	    }
 	    c = cold;
 	    break;
       }
    }
+   if(b->sw == 5) 
+   {  chdir(svdir);
+      getcwd(f->dirct, 80);
+      if((f->ed->dirct = REALLOC(f->ed->dirct, strlen(f->dirct)+1)) == NULL)
+         e_error(e_msg[0], 0, f->fb);
+      else  strcpy(f->ed->dirct, f->dirct);
+      e_close_window(f);
+      return(ESC);
+   }
    e_close_window(f);
-   if(b->sw == 5) return(ESC);
    if(svmode >= 0) f->ed->flopt = svmode;
    return(0);
 }
@@ -1087,14 +1103,14 @@ int e_drucke_datei(f)
    c = e_message(1, str, f);
    if( c != 'Y' ) return(0);
    dp = f->dirct;
-   f->dirct = "/tmp";
+   f->dirct = e_tmp_dir;
    f->ins = 0;
    e_save(f);
    f->dirct=dp;
    f->ins = sins;
-   sprintf(str, "cd /tmp; %s %s", PRNTCMD, f->datnam);
+   sprintf(str, "cd %s; %s %s", e_tmp_dir, PRNTCMD, f->datnam);
    if(system(str)) e_error(e_msg[14], 0, f->fb);
-   sprintf(str, "/tmp/%s", f->datnam);
+   sprintf(str, "%s/%s", e_tmp_dir, f->datnam);
    remove(str);
    return(0);
 }
@@ -1784,8 +1800,7 @@ int e_ed_man(str, f)
 #ifdef XWINDOW
    if(e_we_sw & 1) fk_pointer(WTCUR);
 #endif
-   strcpy(tstr, "/tmp/");
-   strcat(tstr, str);
+   sprintf(tstr, "%s/%s", e_tmp_dir, str);
    for(i=0; (hstr[i] = str[i]) && str[i] != '(' && str[i] != ')'; i++);
    hstr[i] = '\0';
    if(str[i] == '(')
@@ -1796,21 +1811,28 @@ int e_ed_man(str, f)
    for(++i; (nstr[j] = str[i]) && str[i] != ')'
 					&& str[i] != '('; i++, j++);
    nstr[j] = '\0';
+   while(1)
 #ifdef MAN_S_OPT
-   if(!nstr[0])
-   sprintf(command, " man %s > \'%s\' 2> /dev/null", hstr, tstr);
-   else
-   sprintf(command, " man -s %s %s > \'%s\' 2> /dev/null", nstr, hstr, tstr);
+   {  if(!nstr[0])
+         sprintf(command, " man %s > \'%s\' 2> /dev/null", hstr, tstr);
+      else
+         sprintf(command, " man -s %s %s > \'%s\' 2> /dev/null", nstr, hstr, tstr);
 #else
-   sprintf(command, " man %s %s > \'%s\' 2> /dev/null", nstr, hstr, tstr);
+   {  sprintf(command, " man %s %s > \'%s\' 2> /dev/null", nstr, hstr, tstr);
 #endif
-   system(command);
-   chmod(tstr, 0400);
-   f->ed->dtmd = 'h';
-   e_edit(f->ed, tstr);
-   f->ed->dtmd = mdsv;
-   f = f->ed->f[f->ed->mxedt];
-   b = f->b;
+      system(command);
+      chmod(tstr, 0400);
+      f->ed->dtmd = 'h';
+      e_edit(f->ed, tstr);
+      f->ed->dtmd = mdsv;
+      f = f->ed->f[f->ed->mxedt];
+      b = f->b;
+      if(b->mxlines > 1 || !nstr[1]) break;
+      nstr[1] = '\0';
+      chmod(tstr, 0600);
+      remove(tstr);
+      e_close_window(f);
+   }
    if(b->mxlines == 1 && b->bf[0].len == 0)
    {  e_ins_nchar(f->b, f->s, "No manual entry for ", 0, 0, 20);
       e_ins_nchar(f->b, f->s, hstr, b->b.x, b->b.y, strlen(hstr));
@@ -1889,7 +1911,7 @@ struct dirfile *e_make_funct(man)
    if(manpath[0] == '\0') strcpy(manpath, "/usr/man:/usr/local/man");
 #endif
    while(manpath[i])
-   {  for(n = 0; (subpath[n] = manpath[i]) && manpath[i] != ':'; i++, n++);
+   {  for(n = 0; (subpath[n] = manpath[i]) && manpath[i] != PTHD; i++, n++);
       subpath[n] = '\0';
       if(manpath[i]) i++;
 #ifdef CATMAN
