@@ -12,10 +12,9 @@
 #include "edit.h"
 #include <signal.h>
 #ifdef UNIX
-#ifndef TERMCAP
-/* #include <curses.h>  */
-#endif
 #include "attrb.h"
+#include <sys/types.h>
+#include <sys/stat.h>
 #endif
 
 int fk__cursor = 0;
@@ -37,7 +36,9 @@ int harderr(int (*hnd)(_go32_dpmi_registers *r));
 extern FARBE *u_fb, *x_fb;
 #endif
 extern char *info_file;
+extern char *e_tmp_dir;
 int e_switch_screen();
+int e_read_help_str();
 
 char *e_msg[] = {  "Not Enough Memory",
 		   "Option-File got the Wrong Version",
@@ -247,39 +248,7 @@ WOPT oblst_u[] = {  "F1 Help",  0, 0, 2, F1,
 WOPT *eblst, *fblst, *mblst, *dblst, *xblst, *wblst, *rblst;
 WOPT *ablst, *sblst, *hblst, *gblst, *oblst;
 
-char *e_hlp_str[] = {  "\2Editoren-Fenster\5",
-		       "\2Watch-Fenster\5",
-		       "\2Stack-Fenster\5",
-		       "\2Message-Fenster\5",
-		       "\2File-Manager\5",
-		       "\2Execution-Manager\5",    /*  5  */
-		       "\2System-Menue\5",
-		       "\2File-Menue\5",
-		       "\2Edit-Menue\5",
-		       "\2Search-Menue\5",
-		       "\2Block-Menue\5",    /*  10  */
-#ifdef PROG
-		       "\2Run-Menue\5",
-#ifdef DEBUGGER
-		       "\2Debug-Menue\5",
-#endif
-		       "\2Project-Menue\5",
-#endif
-		       "\2Options-Menue\5",
-		       "\2Window-Menue\5",
-		       "\2Help-Menue\5",
-		       "\2Such/Textersatz-Funktion\5",   /*  6 + MENOPT  */
-		       "\2Funktions-Index\5",
-		       "\2Grep-Fenster\5",
-		       "\2Find-Fenster\5",
-		       "\2Project-Fenster\5",        /*  10 + MENOPT  */
-		       "\2Variablen-Fenster\5",
-		       "\2Install-Fenster\5",
-		       "\2Window-Menue\5",
-		       "\2Hauptmenue\5",
-		       "\2Hilfe-Funktion\5"             /*  15 + MENOPT  */
-		    };
-
+extern char *e_hlp_str[];
 
 char *e_hlp, *user_shell;
 WOPT *blst;
@@ -305,6 +274,7 @@ void main(argc, argv)
    ECNT *cn;
    int i, err = 0, g[4];
    int so = 0, sf = 0, sd = 1;
+   char *tp;
 /*
     i = ioctl(0, TCGETA, &tsttermio);
     printf("TCGETA = 0%o\n", TCGETA);
@@ -357,7 +327,7 @@ void main(argc, argv)
    cn->fd.sw = 16;
    cn->fd.sn = 0;
    cn->fd.rn = 0;
-   cn->sdf = cn->rdf = cn->fdf = cn->ddf= cn->hdf = cn->shdf = NULL;
+   cn->sdf = cn->rdf = cn->fdf = cn->ddf = cn->wdf = cn->hdf = cn->shdf = NULL;
    uhr.cn = h_error.cn = cn;
    cn->edtdrct = e_getedpath(argv[0]);
    cn->libdrct = MALLOC(((i=strlen(cn->edtdrct))
@@ -397,12 +367,17 @@ void main(argc, argv)
    e_swap_init(cn);
 #endif
    strcpy(cn->tabs,"        ");
+   e_read_help_str(cn);
    e_hlp = e_hlp_str[0];
 #ifdef DJGPP
    if(!(user_shell = getenv("COMSPEC"))) user_shell = "command.com";
 #else
    if(!(user_shell = getenv("SHELL"))) user_shell = DEF_SHELL;
 #endif
+   e_tmp_dir = MALLOC(128);
+   sprintf(e_tmp_dir, "/tmp/we_%u", (unsigned) getpid());
+   e_tmp_dir = REALLOC(e_tmp_dir, (strlen(e_tmp_dir)+1)*sizeof(char));
+   mkdir(e_tmp_dir, 0700);
    e_edit(cn, "");     /*       Clipboard         */
    
    for(i = 1; i < argc; i++)
@@ -450,6 +425,8 @@ void main(argc, argv)
    uhr.sw = cn->uhr;
    e_ini_schirm();
 #endif
+   if((tp = getenv("INFOPATH")) != NULL)
+            info_file = e_make_string(info_file, tp);
    if(cn->edopt & 1) blst = eblst_u;
    else blst = eblst_o;
    e_ini_desk(cn);
@@ -812,3 +789,5 @@ void e_int_hnd(c)
 }
 
 
+
+
