@@ -46,6 +46,7 @@ int e_men_lst(n, f)
    int i, c = 255, nold = n <= 0 ? 1 : n-1;
    extern OPT opt[];
    extern char *e_hlp, *e_hlp_str[];
+   ECNT *cn = f->ed;
    MOPT *o = MALLOC(MENOPT*sizeof(MOPT));
    for(i = 0; i < MENOPT; i++) o[i].l = 0;
    fk_cursor(0);
@@ -395,7 +396,8 @@ int e_men_lst(n, f)
         	e_optkin("Prev. Alt F7 / Alt V", 0, 'P', e_hp_prev);
    if(n < 0 || n > MENOPT-1) n = 0;
    while (c != ESC)
-   {  if(e_tst_dfkt(f, c) == 0)  {  c = 0; break;  }
+   {  f = cn->f[cn->mxedt];
+      if(e_tst_dfkt(f, c) == 0)  {  c = 0; break;  }
       
       for(i = 0; i < MENOPT; i++)
       if(c == opt[i].s || c == opt[i].as) {  n = i; c = CR;  }
@@ -446,6 +448,7 @@ int e_men_lst(n, f)
       else if(n >= MENOPT) n = 0;
       
    }
+   f = cn->f[cn->mxedt];
    e_pr_str_wsd(opt[nold].x, 0, opt[nold].t, f->fb->mt.fb, 0, 1,
 	f->fb->ms.fb, ( nold == 0 ? 0 : opt[nold].x-e_mn_men),
 	(nold == MENOPT-1) ? MAXSCOL-1 : opt[nold+1].x-e_mn_men-1);
