@@ -13,6 +13,9 @@
 #include <sys/stat.h>
 #endif
 
+#define E_HLP_NUM 27
+char *e_hlp_str[E_HLP_NUM];
+
 extern char *info_file;
 #ifdef DEBUGGER
 extern int e_deb_type;
@@ -2058,4 +2061,34 @@ int e_read_colors(f)
    return(0);
 }
 
+int e_read_help_str(cn)
+     ECNT *cn;
+{
+   FILE *fp;
+   char str[128];
+   int i, len;
+   sprintf(str, "%s/we_hlp_str", cn->libdrct);
+   for(i = 0; i < E_HLP_NUM; i++)
+   {  e_hlp_str[i] = MALLOC(sizeof(char));
+      *e_hlp_str[i] = '\0';
+   }
+   if(!(fp = fopen(str, "rb"))) return(-1);
+   for(i = 0; i < E_HLP_NUM && fgets(str, 128, fp); i++)
+   {
+#ifndef PROG
+      if(i == 11)
+      {  int j;
+         for(j = 0; j < 3; j++) fgets(str, 128, fp);
+      }
+#elif !defined(DEBUGGER)
+      if(i == 12) fgets(str, 128, fp);
+#endif
+      if(str[len=strlen(str)-1] == '\n') str[len] = '\0';
+      else len++;
+      e_hlp_str[i] = REALLOC(e_hlp_str[i], (len+1)*sizeof(char));
+      strcpy(e_hlp_str[i], str);
+   }
+   fclose(fp);
+   return(i == E_HLP_NUM ? 0 : -2);
+}
 
