@@ -52,6 +52,7 @@ int e_save_pid;
 struct dirfile **e_p_df;
 
 extern BUFFER *e_p_m_buffer;
+extern char *e_tmp_dir;
 #ifdef DEBUGGER
 extern int e_d_swtch;
 #endif
@@ -255,23 +256,31 @@ int e_run(f)
 #endif
    if(e_s_prog.exe_name && e_s_prog.exe_name[0])
 #ifndef DJGPP
-   {  if(e_prog.exedir[strlen(e_prog.exedir)-1] == DIRC)
-      sprintf(estr, "%s%s ", e_prog.exedir, e_s_prog.exe_name);
+   {  if(e_s_prog.exe_name[0] == DIRC)
+         sprintf(estr, "%s ", e_s_prog.exe_name);
+      else if(e_prog.exedir[strlen(e_prog.exedir)-1] == DIRC)
+         sprintf(estr, "%s%s ", e_prog.exedir, e_s_prog.exe_name);
       else sprintf(estr, "%s%c%s ", e_prog.exedir, DIRC, e_s_prog.exe_name);
 #else
-   {  if(e_prog.exedir[strlen(e_prog.exedir)-1] == DIRC)
-      sprintf(estr, "go32 %s%s ", e_prog.exedir, e_s_prog.exe_name);
+   {  if(e_s_prog.exe_name[0] == DIRC)
+         sprintf(estr, "go32 %s ", e_s_prog.exe_name);
+      else if(e_prog.exedir[strlen(e_prog.exedir)-1] == DIRC)
+         sprintf(estr, "go32 %s%s ", e_prog.exedir, e_s_prog.exe_name);
       else sprintf(estr, "go32 %s%c%s ", e_prog.exedir, DIRC, e_s_prog.exe_name);
 #endif
    }
    else if(!e__project)
 #ifndef DJGPP
-   {  if(e_prog.exedir[strlen(e_prog.exedir)-1] == DIRC)
-      sprintf(estr, "%s%s", e_prog.exedir, f->datnam);
+   {  if(f->datnam[0] == DIRC)
+         sprintf(estr, "%s", f->datnam);
+      else if(e_prog.exedir[strlen(e_prog.exedir)-1] == DIRC)
+         sprintf(estr, "%s%s", e_prog.exedir, f->datnam);
       else sprintf(estr, "%s%c%s", e_prog.exedir, DIRC, f->datnam);
 #else
-   {  if(e_prog.exedir[strlen(e_prog.exedir)-1] == DIRC)
-      sprintf(estr, "go32 %s%s", e_prog.exedir, f->datnam);
+   {  if(f->datnam[0] == DIRC)
+         sprintf(estr, "go32 %s", f->datnam);
+      else if(e_prog.exedir[strlen(e_prog.exedir)-1] == DIRC)
+         sprintf(estr, "go32 %s%s", e_prog.exedir, f->datnam);
       else sprintf(estr, "go32 %s%c%s", e_prog.exedir, DIRC, f->datnam);
 #endif
       for(len = strlen(estr); len > 0 && estr[len] != '.'; len--);
@@ -281,14 +290,14 @@ int e_run(f)
 #ifndef DJGPP
    else
    {  if(e_prog.exedir[strlen(e_prog.exedir)-1] == DIRC)
-      sprintf(estr, "%sa.out", e_prog.exedir);
-      else sprintf(estr, "%s%ca.out", e_prog.exedir, DIRC);
+      sprintf(estr, "%sa.out ", e_prog.exedir);
+      else sprintf(estr, "%s%ca.out ", e_prog.exedir, DIRC);
    }
 #else
    else
    {  if(e_prog.exedir[strlen(e_prog.exedir)-1] == DIRC)
-      sprintf(estr, "go32 %sa.out", e_prog.exedir);
-      else sprintf(estr, "go32 %s%ca.out", e_prog.exedir, DIRC);
+      sprintf(estr, "go32 %sa.out ", e_prog.exedir);
+      else sprintf(estr, "go32 %s%ca.out ", e_prog.exedir, DIRC);
    }
 #endif
    if(e_prog.arguments) strcat(estr, e_prog.arguments);
@@ -405,14 +414,14 @@ int e_exec_inf(f, argv, n)
    if(pipe(efildes))
       {  e_error(e_p_msg[1], 0, f->fb); return(0); }
 */
-   sprintf(tstr, "/tmp/we_%d_111", (int) getpid());
+   sprintf(tstr, "%s/we_111", e_tmp_dir);
    if((efildes[1] = creat(tstr, 0777)) < 0)
    {  e_error(e_p_msg[1], 0, f->fb); return(0);  }
    if((efildes[0] = open(tstr, O_RDONLY)) < 0 )
    {  e_error(e_p_msg[1], 0, f->fb); return(0);  }
    efile = MALLOC((strlen(tstr)+1)*sizeof(char));
    strcpy(efile, tstr);
-   sprintf(tstr, "/tmp/we_%d_112", (int) getpid());
+   sprintf(tstr, "%s/we_112", e_tmp_dir);
    if((wfildes[1] = creat(tstr, 0777)) < 0)
    {  e_error(e_p_msg[1], 0, f->fb); return(0);  }
    if((wfildes[0] = open(tstr, O_RDONLY)) < 0 )
@@ -1185,7 +1194,7 @@ int e_prj_ob_btt(f, sw)
      int sw;
 {
    FLWND *fw;
-   e_data_first(sw+4, f->ed, "");
+   e_data_first(sw+4, f->ed, f->ed->dirct);
    if(sw > 0)
    {  if(!(f->ed->edopt & 1)) while(e_data_eingabe(f->ed) != AF3);
       else while(e_data_eingabe(f->ed) != CF4);
@@ -1387,6 +1396,7 @@ int e_project(f)
       {  e_switch_window(cn->edt[i], cn->f[cn->mxedt]);
 	 e_close_window(cn->f[cn->mxedt]);
       }
+      f = cn->f[cn->mxedt];
       e_make_prj_opt(f);
       e_prj_ob_file(f);
       return(0);
@@ -2101,7 +2111,12 @@ int e_c_project(f)
 	    break;
 	 case(2):
 	    df = e_p_get_var("EXENAME");
-	    if(e_prog.exedir[strlen(e_prog.exedir)+1] == '/')
+	    elen = strlen(e_prog.exedir)-1;
+#ifdef DJGPP
+	    if(e_prog.exedir[elen] == DIRC || e_prog.exedir[elen] == '/')
+#else
+	    if(e_prog.exedir[elen] == '/')
+#endif
 	    sprintf(ofile, "%s%s", e_prog.exedir,
 			(df && df->name[0][0]) ? df->name[0] : "a.out");
 	    else
@@ -2158,10 +2173,16 @@ int e_c_project(f)
 	    {  for(j = cn->mxedt; j > 0; j--)
 	       if(!strcmp(cn->f[j]->datnam, df->name[k]) && cn->f[j]->save)
 	       e_save(cn->f[j]);
+#ifdef DJGPP
+	       for(j = strlen(df->name[k])-1; j >= 0 && df->name[k][j] != DIRC
+                  && df->name[k][j] != '/' && df->name[k][j] != ':'; j--);
+	       if(e_prog.exedir[elen] == DIRC || e_prog.exedir[elen] == '/')
+#else
 	       for(j = strlen(df->name[k])-1;
 			j >= 0 && df->name[k][j] != DIRC; j--);
 	       if(e_prog.exedir[elen] == '/')
-	       sprintf(ofile, "%s%s ", e_prog.exedir, df->name[k]+j+1);
+#endif
+                  sprintf(ofile, "%s%s ", e_prog.exedir, df->name[k]+j+1);
 	       else sprintf(ofile, "%s/%s ", e_prog.exedir, df->name[k]+j+1);
 	       for(j = strlen(ofile); j > 0 && ofile[j] != '.'; j--);
 	       ofile[j+1] = 'o';
@@ -2461,9 +2482,20 @@ int e_wrt_prj_fl(f)
 {
    int i, len;
    FILE *fp;
-   if((fp = fopen(e_prog.project, "w")) == NULL)
-   {  char text[256];
-      sprintf(text, e_msg[6], e_prog.project);
+   char text[256];
+   for(i = f->ed->mxedt; i > 0 && 
+      (f->ed->f[i]->dtmd != 'D' || f->ed->f[i]->ins != 4); i--);
+#ifdef DJGPP
+   if(i == 0 || e_prog.project[0] == DIRC || e_prog.project[0] == '/'
+      || e_prog.project[1] == ':')
+#else
+   if(i == 0 || e_prog.project[0] == DIRC)
+#endif
+      strcpy(text, e_prog.project);
+   else
+      sprintf(text, "%s/%s", f->ed->f[i]->dirct, e_prog.project);
+   if((fp = fopen(text, "w")) == NULL)
+   {  sprintf(text, e_msg[6], e_prog.project);
       e_error(text, 0, f->fb);
       return(-1);
    }
