@@ -44,7 +44,7 @@
 #define O_SYNC 020
 
 #ifndef TERMCAP
-#include<ncurses/curses.h>
+#include<curses.h>
 #ifndef DJGPP
 #include<term.h>
 #endif
@@ -52,6 +52,7 @@
 */
 #include<signal.h>
 #define KEYFN 42
+#define NSPCHR 13
 
 int MAXSLNS = 24;
 int MAXSCOL = 80;
@@ -62,12 +63,10 @@ char *att_no, *att_so, *att_ul, *att_rv, *att_bl, *att_dm, *att_bo;
 char *ratt_no, *ratt_so, *ratt_ul, *ratt_rv, *ratt_bl, *ratt_dm, *ratt_bo;
 char *beg_scr, *swt_scr, *sav_cur, *res_cur; 
 char *altschirm;
-char *col_fg, *col_bg, *sp_chr;
+char *col_fg, *col_bg, *spc_st, *spc_in, *spc_bg, *spc_nd;
 
 int col_num = 0;
-unsigned int spc[12] = { '+', '+', '+', '+', '-', 
-			 '|', '-', '-', '-', '-', '#', ' '
-		       }; 
+char *sp_chr[NSPCHR];
 
 int cur_x = -1, cur_y = -1;
 struct termio otermio, ntermio, ttermio;
@@ -131,6 +130,20 @@ char *init_kkey(key)
    return(tmp);
 }
 
+char *init_spchr(c)
+     char c;
+{
+   int i;
+   char *pt = NULL;
+   if(!spc_st || !spc_bg || !spc_nd) return(NULL);
+   for(i = 0; spc_st[i] && spc_st[i+1] && spc_st[i] != c; i+=2);
+   if(spc_st[i] && spc_st[i+1])
+   {  pt = MALLOC((strlen(spc_bg)+strlen(spc_nd)+2)*sizeof(char));
+      if(pt) sprintf(pt, "%s%c%s", spc_bg, spc_st[i+1], spc_nd);
+   }
+   return(pt);
+}
+
 int init_cursor()
 {
 /*   int i;     */
@@ -142,7 +155,10 @@ int init_cursor()
    {  if(col_fg) {  free(col_fg);  col_fg = NULL;   }
       if(col_bg) {  free(col_bg);  col_bg = NULL;   }
    }
-   sp_chr = init_key("acsc");
+   spc_st = init_key("acsc");
+   spc_in = init_key("enacs");
+   spc_bg = init_key("smacs");
+   spc_nd = init_key("rmacs");
    att_no = init_key("sgr0");
    att_so = init_key("smso");
    att_ul = init_key("smul");
@@ -225,7 +241,10 @@ int init_cursor()
    {  if(col_fg) {  free(col_fg);  col_fg = NULL;   }
       if(col_bg) {  free(col_bg);  col_bg = NULL;   }
    }
-   sp_chr = init_key("ac");
+   spc_st = init_key("ac");
+   spc_in = init_key("eA");
+   spc_bg = init_key("as");
+   spc_nd = init_key("ae");
    att_no = init_key("me");
    att_so = init_key("so");
    att_ul = init_key("us");
@@ -288,26 +307,19 @@ int init_cursor()
    key_f[40] = init_kkey("kF");
    key_f[41] = init_kkey("@1");
 #endif
-/*
-   if(sp_chr)
-   {  for(i = 0; sp_chr[i] && sp_chr[i+1]; i+=2)
-      {  switch(sp_chr[i])
-         {  case 'j':  spc[0] = sp_chr[i+1];  break;
-            case 'k':  spc[1] = sp_chr[i+1];  break;
-            case 'l':  spc[2] = sp_chr[i+1];  break;
-            case 'm':  spc[3] = sp_chr[i+1];  break;
-            case 'q':  spc[4] = sp_chr[i+1];  break;
-            case 'x':  spc[5] = sp_chr[i+1];  break;
-            case 't':  spc[6] = sp_chr[i+1];  break;
-            case 'u':  spc[7] = sp_chr[i+1];  break;
-            case 'v':  spc[8] = sp_chr[i+1];  break;
-            case 'w':  spc[9] = sp_chr[i+1];  break;
-            case '`':  spc[10] = sp_chr[i+1];  break;
-            case 'a':  spc[11] = sp_chr[i+1];  break;
-	}
-     }
-   }
-*/	    
+   sp_chr[0] = "";
+   if(!(sp_chr[1] = init_spchr('l'))) sp_chr[1] = "+";
+   if(!(sp_chr[2] = init_spchr('k'))) sp_chr[2] = "+";
+   if(!(sp_chr[3] = init_spchr('m'))) sp_chr[3] = "+";
+   if(!(sp_chr[4] = init_spchr('j'))) sp_chr[4] = "+";
+   if(!(sp_chr[5] = init_spchr('q'))) sp_chr[5] = "-";
+   if(!(sp_chr[6] = init_spchr('x'))) sp_chr[6] = "|";
+   if(!(sp_chr[7] = init_spchr('w'))) sp_chr[7] = "_";
+   if(!(sp_chr[8] = init_spchr('t'))) sp_chr[8] = "|";
+   if(!(sp_chr[9] = init_spchr('m'))) sp_chr[9] = "|";
+   if(!(sp_chr[10] = init_spchr('q'))) sp_chr[10] = "_";
+   if(!(sp_chr[11] = init_spchr('`'))) sp_chr[11] = "#";
+   if(!(sp_chr[12] = init_spchr('a'))) sp_chr[12] = " ";
    return(0);
 }
 /*
@@ -361,6 +373,7 @@ int e_t_initscr()
    ntermio.c_cc[VSWTCH] = 0;
 #endif
    ioctl(0, TCSETA, &ntermio);
+   if(spc_in) e_putp(spc_in);
    return(0);
 }
 
@@ -483,7 +496,7 @@ void fk_colset(c)
 
 int e_t_refresh()
 {
-   int x = cur_x, y = cur_y, i, j;
+   int x = cur_x, y = cur_y, i, j, c;
    fk_cursor(0);
    for(i = 0; i < MAXSLNS; i++)
    for(j = 0; j < MAXSCOL; j++)
@@ -501,7 +514,8 @@ int e_t_refresh()
 	 {  cur_x = 0;  cur_y = i+1;  }
 	 if(col_num <= 0) fk_attrset(e_gt_col(j, i));
 	 else fk_colset(e_gt_col(j, i));
-	 fputc(e_gt_char(j, i), stdout);
+         if((c = e_gt_char(j, i)) < NSPCHR) e_putp(sp_chr[c]);
+         else fputc(e_gt_char(j, i), stdout);
 	 *(altschirm + 2*MAXSCOL * i + 2 * j) = *(schirm + 2*MAXSCOL * i + 2 * j);
 	 *(altschirm + 2*MAXSCOL * i + 2 * j + 1) = *(schirm + 2*MAXSCOL * i + 2 * j + 1);
       }
