@@ -12,7 +12,7 @@
 #include<dirent.h>
 #ifndef TERMCAP
 #ifndef DJGPP
-#include<ncurses/curses.h>
+#include<curses.h>
 /*  #include<term.h>   */
 #endif
 #endif
@@ -162,8 +162,18 @@ int e_ini_unix(argc, argv)
    }
    else
 #endif
+   {  fk_u_cursor = fk_t_cursor;
+      fk_u_locate = fk_t_locate;
+#ifndef DJGPP
+      e_u_refresh = e_t_refresh;
+#endif
+      e_u_getch = e_t_getch;
+      e_u_sys_ini = e_t_sys_ini;
+      e_u_sys_end = e_t_sys_end;
+      fk_u_putchar = fk_t_putchar;
+      fk_mouse = fk_t_mouse;
 #ifdef DJGPP
-   {  e_we_sw |= 1;
+      e_we_sw |= 1;
       e_s_u_clr = e_s_x_clr;
       e_n_u_clr = e_n_x_clr;
       e_pr_u_col_kasten = e_pr_x_col_kasten;
@@ -171,7 +181,7 @@ int e_ini_unix(argc, argv)
       u_bioskey = x_bioskey;
       e_t_initscr();
 #else
-   {  e_t_initscr();
+      e_t_initscr();
       if(col_num > 0)
       {   e_pr_u_col_kasten = e_pr_x_col_kasten;
           e_frb_u_menue = e_frb_x_menue;
@@ -185,33 +195,42 @@ int e_ini_unix(argc, argv)
 	  e_n_u_clr = e_n_t_clr;
       }
 #endif
-      fk_u_cursor = fk_t_cursor;
-      fk_u_locate = fk_t_locate;
-#ifndef DJGPP
-      e_u_refresh = e_t_refresh;
-#endif
-      e_u_getch = e_t_getch;
-      e_u_sys_ini = e_t_sys_ini;
-      e_u_sys_end = e_t_sys_end;
-      fk_u_putchar = fk_t_putchar;
-      fk_mouse = fk_t_mouse;
 #ifndef DJGPP
       MCI = '+';
       MCA = '0';
+      RD1 = '\01';
+      RD2 = '\02';
+      RD3 = '\03';
+      RD4 = '\04';
+      RD5 = '\05';
+      RD6 = '\06';
+      RE1 = '\01';
+      RE2 = '\02';
+      RE3 = '\03';
+      RE4 = '\04';
+      RE5 = '\05';
+      RE6 = '\06';
+      WBT = '\13';
+      ctree[0] = "\11\12\07";   /*  07 -> 30  */
+      ctree[1] = "\11\12\12";	/*  11 -> 16  */
+      ctree[2] = "\11\07\12";   /*  12 -> 22  */
+      ctree[3] = "\10\12\12";   /*  10 -> 25  */
+      ctree[4] = "\11\12\12";
+/*
       RD1 = spc[2];
       RD2 = spc[1];
       RD3 = spc[3];
       RD4 = spc[0];
       RD5 = spc[4];
       RD6 = spc[5];
-/*
+*//*
       RD1 = '+';
       RD2 = '+';
       RD3 = '+';
       RD4 = '+';
       RD5 = '-';
       RD6 = '|';
-*/
+*//*
       RE1 = '.';
       RE2 = '.';
       RE3 = '.';
@@ -224,6 +243,7 @@ int e_ini_unix(argc, argv)
       ctree[2] = "|__";
       ctree[3] = "|__";
       ctree[4] = "|__";
+*/
 #else
       MCI = '\xb1';
       MCA = '\xfe';
@@ -506,7 +526,7 @@ struct dirfile *e_find_files(sufile, sw)
    else
    {  sdir = MALLOC((n+1) * sizeof(char));
       for(i = 0; i < n; i++) sdir[i] = sufile[i];
-      sufile[n] = '\0';
+      sdir[n] = '\0';
    }
    if(!(dirp = opendir(sdir))) {  FREE(sdir); return(df);  }
    while((dp = readdir(dirp)) != NULL)
@@ -514,12 +534,13 @@ struct dirfile *e_find_files(sufile, sw)
       if(!e_compstr(sfile, dp->d_name))
       {  stat(e_mkfilepath(sdir, dp->d_name, stmp), buf);
 #ifdef DJGPP
-	 if(!(buf->st_mode & S_IFDIR) && (!(sw & 2) ||
+	 if(((buf->st_mode & S_IFMT) == S_IFREG) && (!(sw & 2) ||
 	   ((n = strlen(dp->d_name)) > 3 && ( !strcmp(dp->d_name+n-4, ".exe")
 		|| !strcmp(dp->d_name+n-4, ".com")
 		|| !strcmp(dp->d_name+n-4, ".bat") )) ))
 #else
-	 if(!(buf->st_mode & S_IFDIR) && (!(sw & 2) || (buf->st_mode & 0111)))
+	 if(((buf->st_mode & S_IFMT) == S_IFREG) && 
+            (!(sw & 2) || (buf->st_mode & 0111)))
 #endif
 	 {  if(df->anz == 0) df->name = MALLOC((df->anz + 1) * sizeof(char *));
 	    else df->name = REALLOC(df->name, (df->anz + 1) * sizeof(char *));
@@ -574,7 +595,7 @@ struct dirfile *e_find_dir(sufile, sw)
    else
    {  sdir = MALLOC((n+1) * sizeof(char));
       for(i = 0; i < n; i++) sdir[i] = sufile[i];
-      sufile[n] = '\0';
+      sdir[n] = '\0';
    }
    if(!(dirp = opendir(sdir))) {  FREE(sdir);  return(df);  }
    while((dp = readdir(dirp)) != NULL)
@@ -582,7 +603,7 @@ struct dirfile *e_find_dir(sufile, sw)
       if(!e_compstr(sfile, dp->d_name) && strcmp(dp->d_name, ".")
                                              && strcmp(dp->d_name, ".."))
       {  stat(e_mkfilepath(sdir, dp->d_name, stmp), buf);
-	 if((buf->st_mode & S_IFDIR))
+	 if((buf->st_mode & S_IFMT) == S_IFDIR)
 	 {  if(df->anz == 0) df->name = MALLOC((df->anz + 1) * sizeof(char *));
 	    else df->name = REALLOC(df->name, (df->anz + 1) * sizeof(char *));
 	    if(df->name == NULL || !(tmpst = MALLOC(strlen(dp->d_name)+1)))
@@ -672,9 +693,13 @@ int e_recover(cn)
 	 e_close_window(f);
       }
       else f->save = 1;
+#ifdef PROG
+      if(e_we_sw & 2) e_add_synt_tl(f->datnam, f);
+#endif
+      if((f->ed->edopt & 256) || ((f->ed->edopt & 128) && f->c_st)) 
+         f->flg = 1;
    }
    freedf(files);
-   if(f && cn->edopt & 8) e_sc_all(f, 1);
    return(0);
 }
 
