@@ -1599,7 +1599,7 @@ int e_mess_win(header, str, pic, f)
 #if MOUSE
    extern struct mouse e_mouse;
 #endif
-   int xa, ya, xe, ye, anz = 0, mxlen = 0, i, j, k, max = 0.8*MAXSCOL;
+   int xa, ya, xe, ye, num, anz = 0, mxlen = 0, i, j, k, max = 0.8*MAXSCOL;
    char **s = MALLOC(sizeof(char*));
    for(k = 0, i = 0; str[i]; i++)
    {  if((i-k) == max || str[i] == '\n')
@@ -1627,6 +1627,13 @@ int e_mess_win(header, str, pic, f)
    ye = ya + anz + 5;
    xa = (MAXSCOL - mxlen - 6)/2;
    xe = xa + mxlen + 6;
+   if(ya < 2) ya = 2;
+   if(ye > MAXSLNS-3) ye = MAXSLNS - 3;
+   num = anz;
+   if(num > ye - ya - 5)
+   {  num = ye - ya - 5;
+      strcpy(s[num-1], "...");
+   }
    
    if(!(*pic) || (*pic)->e.x != xe || (*pic)->a.x != xa || (*pic)->e.x < xe)
    {  *pic = e_change_pic(xa, ya, xe, ye, *pic, 1, f->fb->nt.fb);
@@ -1640,7 +1647,7 @@ int e_mess_win(header, str, pic, f)
    e_std_rahmen(xa, ya, xe, ye, header, 1, f->fb->nr.fb, f->fb->ne.fb);
    for(i = xa + 1; i < xe; i++)
    e_pr_char(i, ya+1, ' ', f->fb->nr.fb);
-   for(j = 0; j < anz; j++)
+   for(j = 0; j < num; j++)
    {  e_pr_char(xa+1, ya+2+j, ' ', f->fb->nt.fb);
       e_pr_char(xa+2, ya+2+j, ' ', f->fb->nt.fb);
       e_pr_str(xa+3, ya+2+j, s[j], f->fb->nt.fb, 0, 0, 0, 0);
@@ -1650,6 +1657,8 @@ int e_mess_win(header, str, pic, f)
    for(j += ya+2; j < ye-2; j++)
    for(i = xa + 1; i < xe; i++)
    e_pr_char(i, j, ' ', f->fb->nt.fb);
+   for(i = 0; i < anz; i++) FREE(s[i]);
+   FREE(s);
 #ifdef DJGPP
    while(i = e_kbhit())
    {  if(i == -1 && e_mouse.y == ye-2
