@@ -58,11 +58,13 @@ int e_x_change();
 #define OK 0
 #define BUFSIZE 80
 
+extern char *e_tmp_dir;
+
 /*  Globale Konstanten  */
 
 /*  Fuer XWindow   */
 Display *display = NULL;
-int screen;
+int screen, altmask = ALTMASK;
 Window win, root;
 GC gc;
 XFontStruct *font_info;
@@ -550,6 +552,17 @@ int e_read_x_opt(fontname, geometry, initial)
    if((tmp = XGetDefault(display, progname, "color14")) != NULL) e_x_colname[13] = tmp;
    if((tmp = XGetDefault(display, progname, "color15")) != NULL) e_x_colname[14] = tmp;
    if((tmp = XGetDefault(display, progname, "color16")) != NULL) e_x_colname[15] = tmp;
+   if((tmp = XGetDefault(display, progname, "altmask")) != NULL)
+   {  if(!strncmp(tmp, "mod", 3)) i = atoi(tmp+3);
+      else i = 0;
+      switch(i)
+      {  case 1:  altmask = Mod1Mask;  break;
+         case 2:  altmask = Mod2Mask;  break;
+         case 3:  altmask = Mod3Mask;  break;
+         case 4:  altmask = Mod4Mask;  break;
+         case 5:  altmask = Mod5Mask;  break;
+      }
+   }
    return(0);
 }
 
@@ -624,11 +637,14 @@ int e_x_initscr(argc, argv)
    icon_pixmap = XCreateBitmapFromData(display, win, icon_bitmap_bits,
 	icon_bitmap_width, icon_bitmap_height);
    
-   size_hints.flags = USPosition | USSize | PPosition | PSize | PMinSize;
+   size_hints.flags = USPosition | USSize | PPosition | PSize 
+      | PResizeInc | PMinSize;
    size_hints.x = x;
    size_hints.y = y;
    size_hints.width = width;
    size_hints.height = height;
+   size_hints.width_inc = font_width;
+   size_hints.height_inc = font_height;
    size_hints.min_width = font_width * 80;
    size_hints.min_height = font_height * 24;
    
@@ -830,8 +846,8 @@ int e_x_change(pic)
 	 case ConfigureNotify:
             {  size_hints.width = (report.xconfigure.width / font_width) * font_width;
 	       size_hints.height = (report.xconfigure.height / font_height) * font_height;
-	       XResizeWindow(display, win, size_hints.width, size_hints.height);
-	       if(size_hints.width != MAXSCOL * font_width ||
+/*	       XResizeWindow(display, win, size_hints.width, size_hints.height);
+*/	       if(size_hints.width != MAXSCOL * font_width ||
                   size_hints.height != MAXSLNS * font_height)
 	       {  extern struct EXT h_error;
                   e_x_repaint_desk(h_error.cn->f[h_error.cn->mxedt]);
@@ -852,7 +868,7 @@ int e_x_change(pic)
 	    if(report.xbutton.button == 1)
 	    {  e_mouse.k = (key_b & ShiftMask) ? 3 : 0 +
 		         (key_b & ControlMask) ? 4 : 0 +
-		         (key_b & ALTMASK) ? 8 : 0;
+		         (key_b & altmask) ? 8 : 0;
 	       e_mouse.x = report.xbutton.x/font_width;
 	       e_mouse.y = report.xbutton.y/font_height;
 	       if(e_mouse.x > (pic->e.x + pic->a.x - 10)/2
@@ -911,8 +927,8 @@ int e_x_getch()
 	 case ConfigureNotify:
             {  size_hints.width = (report.xconfigure.width / font_width) * font_width;
 	       size_hints.height = (report.xconfigure.height / font_height) * font_height;
-	       XResizeWindow(display, win, size_hints.width, size_hints.height);
-	       if(size_hints.width != MAXSCOL * font_width ||
+/*	       XResizeWindow(display, win, size_hints.width, size_hints.height);
+*/	       if(size_hints.width != MAXSCOL * font_width ||
                   size_hints.height != MAXSLNS * font_height)
 	       {  extern struct EXT h_error;
                   e_x_repaint_desk(h_error.cn->f[h_error.cn->mxedt]);
@@ -943,10 +959,10 @@ int e_x_getch()
 	       if(*buffer == 127)
 	       {  if(key_b & ControlMask) return(CENTF);
 		  else if(key_b & ShiftMask) return(ShiftDel);
-		  else if(key_b & ALTMASK) return(AltDel);
+		  else if(key_b & altmask) return(AltDel);
 		  else return(ENTF);
 	       }
-	       if(key_b & ALTMASK)
+	       if(key_b & altmask)
 	       c = e_tast_sim(key_b & ShiftMask ?
 					toupper(*buffer) : *buffer);
 	       else return(*buffer);
@@ -975,7 +991,7 @@ int e_x_getch()
 		  else if(keysym == XK_F9) c = CF9;
 		  else if(keysym == XK_F10) c = CF10;
 	       }
-	       else if(key_b & ALTMASK)
+	       else if(key_b & altmask)
 	       {  if(keysym == XK_F1) c = AF1;
 		  else if(keysym == XK_F2) c = AF2;
 		  else if(keysym == XK_F3) c = AF3;
@@ -1034,7 +1050,7 @@ int e_x_getch()
 				      &root_x, &root_y, &x, &y, &key_b);
 	    e_mouse.k = (key_b & ShiftMask) ? 3 : 0 +
 			    (key_b & ControlMask) ? 4 : 0 +
-			    (key_b & ALTMASK) ? 8 : 0;
+			    (key_b & altmask) ? 8 : 0;
 	    e_mouse.x = report.xbutton.x/font_width;
 	    e_mouse.y = report.xbutton.y/font_height;
 	    c = 0;
@@ -1133,7 +1149,7 @@ int e_x_system(exe)
    int ret;
    char file[80];
    char *string;
-   sprintf(file, "/tmp/we_%d_sys_tmp", (int) getpid());
+   sprintf(file, "%s/we_sys_tmp", e_tmp_dir);
    string = MALLOC(strlen(exe) + strlen(file) + strlen(user_shell) + 40);
    if( !(fp = fopen(file, "w+") ) )
    {  FREE(string);  return(-1);  }
